@@ -96,47 +96,37 @@ async fn collect(regions: Vec<String>, vpc: Vec<String>) -> Result<(), ec2::Erro
 
         progress.finish();
 
-        let mut trees = vec![];
-        // for vpc in aws.vpcs().iter().filter_map(|vpc| vpc.vpc_id()) {
-        for vpc in aws.vpcs() {
-            let mut tree = ptree::TreeBuilder::new(vpc.id_and_name());
-            let vpc_id = vpc.id();
-            add_children(&mut tree, "Subnets", aws.subnets(&vpc_id));
-            add_children(&mut tree, "Instances", aws.instances(&vpc_id));
-            add_children(
-                &mut tree,
-                "Internet Gateways",
-                aws.internet_gateways(&vpc_id),
-            );
-            add_children(&mut tree, "Route Tables", aws.route_tables(&vpc_id));
-            add_children(&mut tree, "Network ACLs", aws.network_acls(&vpc_id));
-            add_children(
-                &mut tree,
-                "VPC Peering Connections",
-                aws.vpc_peerings(&vpc_id),
-            );
-            add_children(&mut tree, "VPC Endpoints", aws.vpc_endpoints(&vpc_id));
-            add_children(&mut tree, "NAT Gateways", aws.nat_gateways(&vpc_id));
-            add_children(&mut tree, "Security Groups", aws.security_groups(&vpc_id));
-            add_children(&mut tree, "VPN Connections", aws.vpn_connections(&vpc_id));
-            add_children(&mut tree, "VPN Gateways", aws.vpn_gateways(&vpc_id));
-            add_children(
-                &mut tree,
-                "Network Interfaces",
-                aws.network_interfaces(&vpc_id),
-            );
-
-            trees.push(tree.build())
-        }
-
-        trees
-            .into_iter()
-            .for_each(|tree| ptree::print_tree(&tree).expect("Failed to print tree"));
+        aws.vpcs()
+            .iter()
+            .map(|vpc| vpc_tree(&aws, vpc))
+            .for_each(|tree| {
+                println!();
+                ptree::print_tree(&tree).expect("Failed to print tree");
+            });
     }
 
     Ok(())
 }
 
+fn vpc_tree(aws: &aws::AwsResources, vpc: &ec2::model::Vpc) -> ptree::item::StringItem {
+    let mut tree = ptree::TreeBuilder::new(vpc.id_and_name());
+    let tree = &mut tree;
+    let vpc_id = vpc.id();
+    add_children(tree, "Subnets", aws.subnets(&vpc_id));
+    add_children(tree, "Instances", aws.instances(&vpc_id));
+    add_children(tree, "Internet Gateways", aws.internet_gateways(&vpc_id));
+    add_children(tree, "Route Tables", aws.route_tables(&vpc_id));
+    add_children(tree, "Network ACLs", aws.network_acls(&vpc_id));
+    add_children(tree, "VPC Peering Connections", aws.vpc_peerings(&vpc_id));
+    add_children(tree, "VPC Endpoints", aws.vpc_endpoints(&vpc_id));
+    add_children(tree, "NAT Gateways", aws.nat_gateways(&vpc_id));
+    add_children(tree, "Security Groups", aws.security_groups(&vpc_id));
+    add_children(tree, "VPN Connections", aws.vpn_connections(&vpc_id));
+    add_children(tree, "VPN Gateways", aws.vpn_gateways(&vpc_id));
+    add_children(tree, "Network Interfaces", aws.network_interfaces(&vpc_id));
+    tree.build()
+}
+
 fn add_children(ptree: &mut ptree::TreeBuilder, title: impl ToString, resources: Vec<impl Show>) {
     if !resources.is_empty() {
         ptree.begin_child(title.to_string());
